@@ -22,7 +22,7 @@ class VolumeObject : public PulseObject
     Q_PROPERTY(bool volumeWritable READ isVolumeWritable NOTIFY isVolumeWritableChanged)
     Q_PROPERTY(QStringList channels READ channels NOTIFY channelsChanged)
     Q_PROPERTY(QStringList rawChannels READ rawChannels NOTIFY rawChannelsChanged)
-    Q_PROPERTY(QVector<qint64> channelVolumes READ channelVolumes WRITE setChannelVolumes NOTIFY channelVolumesChanged)
+    Q_PROPERTY(QList<qint64> channelVolumes READ channelVolumes WRITE setChannelVolumes NOTIFY channelVolumesChanged)
 public:
     explicit VolumeObject(QObject *parent);
     ~VolumeObject() override;
@@ -73,8 +73,8 @@ public:
     QStringList channels() const;
     QStringList rawChannels() const;
 
-    QVector<qint64> channelVolumes() const;
-    virtual void setChannelVolumes(const QVector<qint64> &channelVolumes) = 0;
+    QList<qint64> channelVolumes() const;
+    virtual void setChannelVolumes(const QList<qint64> &channelVolumes) = 0;
     Q_INVOKABLE virtual void setChannelVolume(int channel, qint64 volume) = 0;
 
 Q_SIGNALS:
